@@ -18,7 +18,14 @@
 import mygpoclient
 
 import os
-import urllib
+
+try:
+    # Python 3
+    from urllib.parse import quote_plus, quote
+
+except ImportError:
+    # Python 2
+    from urllib import quote_plus, quote
 
 from mygpoclient import util
 
@@ -33,11 +40,17 @@ class Locator(object):
 
     SETTINGS_TYPES = ('account', 'device', 'podcast', 'episode')
 
-    def __init__(self, username, host=mygpoclient.HOST,
+    def __init__(self, username, root_url=mygpoclient.ROOT_URL,
             version=mygpoclient.VERSION):
         self._username = username
-        self._simple_base = 'http://%(host)s' % locals()
-        self._base = 'http://%(host)s/api/%(version)s' % locals()
+        if root_url.endswith('/'):
+            root_url = root_url[:-1]
+        if root_url.startswith('http'):
+            self._simple_base = root_url
+            self._base = '%(root_url)s/api/%(version)s' % locals()
+        else:
+            self._simple_base = 'http://%(root_url)s' % locals()
+            self._base = 'http://%(root_url)s/api/%(version)s' % locals()
 
     def _convert_since(self, since):
         """Convert "since" into a numeric value
@@ -49,7 +62,7 @@ class Locator(object):
         except ValueError:
             raise ValueError('since must be a numeric value (or None)')
 
-    def subscriptions_uri(self, device_id, format='opml'):
+    def subscriptions_uri(self, device_id=None, format='opml'):
         """Get the Simple API URI for a subscription list
 
         >>> locator = Locator('john')
@@ -61,9 +74,13 @@ class Locator(object):
         if format not in self.SIMPLE_FORMATS:
             raise ValueError('Unsupported file format')
 
-        filename = '%(device_id)s.%(format)s' % locals()
+        username = self._username
+        if device_id is None:
+            path = '%(username)s.%(format)s' % locals()
+        else:
+            path = '%(username)s/%(device_id)s.%(format)s' % locals()
         return util.join(self._simple_base,
-                'subscriptions', self._username, filename)
+                'subscriptions', path)
 
     def toplist_uri(self, count=50, format='opml'):
         """Get the Simple API URI for the toplist
@@ -113,7 +130,7 @@ class Locator(object):
         if format not in self.SIMPLE_FORMATS:
             raise ValueError('Unsupported file format')
 
-        query = urllib.quote_plus(query)
+        query = quote_plus(query)
         filename = 'search.%(format)s?q=%(query)s' % locals()
         return util.join(self._simple_base, filename)
 
@@ -201,7 +218,7 @@ class Locator(object):
             params.append(('device', device_id))
 
         if params:
-            filename += '?' + '&'.join('%s=%s' % (key, urllib.quote(value)) for key, value in params)
+            filename += '?' + '&'.join('%s=%s' % (key, quote(value)) for key, value in params)
 
         return util.join(self._base, 'episodes', filename)
 
@@ -256,9 +273,9 @@ class Locator(object):
         >>> locator.podcast_data_uri('http://podcast.com')
         'http://gpodder.net/api/2/data/podcast.json?url=http%3A//podcast.com'
         """
-        filename = 'podcast.json?url=%s' % urllib.quote(podcast_url) 
+        filename = 'podcast.json?url=%s' % quote(podcast_url)
         return util.join(self._base, 'data', filename)
-    
+
     def episode_data_uri(self, podcast_url, episode_url):
         """Get the Advanced API URI for retrieving Episode Data
 
@@ -266,7 +283,7 @@ class Locator(object):
         >>> locator.episode_data_uri('http://podcast.com','http://podcast.com/foo')
         'http://gpodder.net/api/2/data/episode.json?podcast=http%3A//podcast.com&url=http%3A//podcast.com/foo'
         """
-        filename = 'episode.json?podcast=%s&url=%s' % (urllib.quote(podcast_url), urllib.quote(episode_url))
+        filename = 'episode.json?podcast=%s&url=%s' % (quote(podcast_url), quote(episode_url))
         return util.join(self._base, 'data', filename)
 
     def favorite_episodes_uri(self):
@@ -281,7 +298,7 @@ class Locator(object):
 
     def settings_uri(self, type, scope_param1, scope_param2):
         """Get the Advanced API URI for retrieving or saving Settings
-        
+
         Depending on the Type of setting scope_param2 or scope_param1 and scope_param2 are
         not necessary.
 
@@ -308,11 +325,20 @@ class Locator(object):
         if type is 'podcast':
             if scope_param1 is None:
                 raise ValueError('Podcast URL not specified')
-            filename += '?podcast=%s' % urllib.quote(scope_param1)
+            filename += '?podcast=%s' % quote(scope_param1)
 
         if type is 'episode':
             if (scope_param1 is None) or (scope_param2 is None):
                 raise ValueError('Podcast or Episode URL not specified')
-            filename += '?podcast=%s&episode=%s' % (urllib.quote(scope_param1), urllib.quote(scope_param2))
+            filename += '?podcast=%s&episode=%s' % (quote(scope_param1), quote(scope_param2))
 
         return util.join(self._base, 'settings' , filename)
+
+    def root_uri(self):
+        """ Get the server's root URI.
+
+        >>> locator = Locator(None)
+        >>> locator.root_uri()
+        'http://gpodder.net'
+        """
+        return self._simple_base
